@@ -14,6 +14,9 @@ for module_file in Path(__file__).parent.glob("*.py"):
         importlib.import_module(module_name, PACKAGE_BASE)
 
 # https://setuptools.readthedocs.io/en/latest/userguide/entry_point.html
-eps = metadata.entry_points().get('dpdata.plugins', [])
+try:
+    eps = metadata.entry_points(group='dpdata.plugins')
+except TypeError:
+    eps = metadata.entry_points().get('dpdata.plugins', [])
 for ep in eps:
     plugin = ep.load()
