@@ -4,7 +4,7 @@ from dpdata.format import Format
 @Format.register("fhi_aims/md")
 @Format.register("fhi_aims/output")
 class FhiMDFormat(Format):
-    def from_labeled_system(self, file_name, md=True, begin = 0, step = 1, **kwargs):
+    def from_labeled_system(self, file_name, md=True, begin = 0, step = 1, convergence_check=True, **kwargs):
         data = {}
         data['atom_names'], \
             data['atom_numbs'], \
@@ -14,7 +14,7 @@ class FhiMDFormat(Format):
             data['energies'], \
             data['forces'], \
             tmp_virial, \
-            = dpdata.fhi_aims.output.get_frames(file_name, md = md, begin = begin, step = step)
+            = dpdata.fhi_aims.output.get_frames(file_name, md = md, begin = begin, step = step, convergence_check=convergence_check)
         if tmp_virial is not None :
             data['virials'] = tmp_virial
         return data
