@@ -1,7 +1,7 @@
 import numpy as np
 
 from dpdata.xyz.quip_gap_xyz import QuipGapxyzSystems
-from dpdata.xyz.xyz import coord_to_xyz
+from dpdata.xyz.xyz import coord_to_xyz, xyz_to_coord
 from dpdata.format import Format
 
 @Format.register("xyz")
@@ -20,6 +20,20 @@ class XYZFormat(Format):
         with open(file_name, 'w') as fp:
             fp.write("\n".join(buff))
 
+    def from_system(self, file_name, **kwargs):
+        with open(file_name, 'r') as fp:
+            coords, types = xyz_to_coord(fp.read())
+        atom_names, atom_types, atom_numbs = np.unique(types,  return_inverse=True, return_counts=True)
+        return {
+            'atom_names': list(atom_names),
+            'atom_numbs': list(atom_numbs),
+            'atom_types': atom_types,
+            'coords': coords.reshape((1, *coords.shape)),
+            'cells': np.eye(3).reshape((1, 3, 3)) * 100,
+            'nopbc': True,
+            'orig': np.zeros(3),
+        }
+
 
 @Format.register("quip/gap/xyz")
 @Format.register("quip/gap/xyz_file")
@@ -29,4 +43,4 @@ class QuipGapXYZFormat(Format):
 
     def from_multi_systems(self, file_name, **kwargs):
         # here directory is the file_name
-        return QuipGapxyzSystems(file_name)
\ No newline at end of file
+        return QuipGapxyzSystems(file_name)
