@@ -18,10 +18,8 @@ class CompSys :
                          self.system_2.data['atom_names'])
 
     def test_atom_types(self):
-        self.assertEqual(self.system_1.data['atom_types'][0], 
-                         self.system_2.data['atom_types'][0])
-        self.assertEqual(self.system_1.data['atom_types'][1],
-                         self.system_2.data['atom_types'][1])
+        np.testing.assert_array_equal(self.system_1.data['atom_types'],
+                                      self.system_2.data['atom_types'])
 
     def test_orig(self):
         for d0 in range(3) :
@@ -56,6 +54,10 @@ class CompSys :
     def test_nopbc(self):
         self.assertEqual(self.system_1.nopbc, self.system_2.nopbc)
 
+    def test_data_check(self):
+        self.system_1.check_data()
+        self.system_2.check_data()
+
 
 class CompLabeledSys (CompSys) :
     def test_energy(self) :
