@@ -3,4 +3,6 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')
 import dpdata
 import dpdata.md.water
 import dpdata.md.msd
+import dpdata.gaussian.gjf
 import dpdata.system
+import dpdata.stat
